@@ -1,6 +1,6 @@
 use std::fmt;
 
-use crate::{Argument, Directive, InputValueDef, SelectionSet, StringValue, Type_};
+use crate::{Argument, Directive, InputValueDefinition, SelectionSet, StringValue, Type_};
 /// The FieldDefinition type represents each field definition in an Object
 /// definition or Interface type definition.
 ///
@@ -11,7 +11,7 @@ use crate::{Argument, Directive, InputValueDef, SelectionSet, StringValue, Type_
 ///
 /// ### Example
 /// ```rust
-/// use apollo_encoder::{Type_, FieldDefinition, InputValueDef};
+/// use apollo_encoder::{Type_, FieldDefinition, InputValueDefinition};
 ///
 /// let ty_1 = Type_::NamedType {
 ///     name: "CatBreed".to_string(),
@@ -23,7 +23,7 @@ use crate::{Argument, Directive, InputValueDef, SelectionSet, StringValue, Type_
 ///     name: "CatBreed".to_string(),
 /// };
 ///
-/// let arg = InputValueDef::new("breed".to_string(), value_1);
+/// let arg = InputValueDefinition::new("breed".to_string(), value_1);
 ///
 /// field.arg(arg);
 ///
@@ -39,7 +39,7 @@ pub struct FieldDefinition {
     // Description may return a String.
     description: StringValue,
     // Args returns a List of __InputValue representing the arguments this field accepts.
-    args: Vec<InputValueDef>,
+    args: Vec<InputValueDefinition>,
     // Type must return a __Type that represents the type of value returned by this field.
     type_: Type_,
     /// Contains all directives.
@@ -66,7 +66,7 @@ impl FieldDefinition {
     }
 
     /// Set the Field's arguments.
-    pub fn arg(&mut self, arg: InputValueDef) {
+    pub fn arg(&mut self, arg: InputValueDefinition) {
         self.args.push(arg);
     }
 
@@ -165,7 +165,10 @@ impl Field {
     /// Should be used everywhere in this crate instead of the Display implementation
     /// Display implementation is only useful as a public api
     pub(crate) fn format_with_indent(&self, indent_level: usize) -> String {
-        let mut text = String::from(&self.name);
+        let mut text = match &self.alias {
+            Some(alias) => format!("{alias}: {}", self.name),
+            None => String::from(&self.name),
+        };
 
         if !self.args.is_empty() {
             for (i, arg) in self.args.iter().enumerate() {
@@ -193,30 +196,7 @@ impl Field {
 impl fmt::Display for Field {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         let indent_level = 0;
-
-        if let Some(alias) = &self.alias {
-            write!(f, "{}: ", alias)?;
-        }
-        write!(f, "{}", self.name)?;
-
-        if !self.args.is_empty() {
-            for (i, arg) in self.args.iter().enumerate() {
-                match i {
-                    0 => write!(f, "({}", arg)?,
-                    _ => write!(f, ", {}", arg)?,
-                }
-            }
-            write!(f, ")")?;
-        }
-
-        for directive in &self.directives {
-            write!(f, " {}", directive)?;
-        }
-        if let Some(sel_set) = &self.selection_set {
-            write!(f, " {}", sel_set.format_with_indent(indent_level))?;
-        }
-
-        Ok(())
+        write!(f, "{}", self.format_with_indent(indent_level))
     }
 }
 
@@ -306,7 +286,7 @@ mod tests {
         let value_2 = Type_::List {
             ty: Box::new(value_1),
         };
-        let mut arg = InputValueDef::new("cat".to_string(), value_2);
+        let mut arg = InputValueDefinition::new("cat".to_string(), value_2);
         let mut deprecated_directive = Directive::new(String::from("deprecated"));
         deprecated_directive.arg(Argument::new(
             String::from("reason"),
